package com.biganto.visual.roompark.domain.model

import com.biganto.visual.roompark.data.repository.api.retrofit.raw.EstateRaw
import com.biganto.visual.roompark.data.repository.db.requrey.model.EstateEntity
import com.biganto.visual.roompark.data.repository.db.requrey.model.ExplicationEntity

/**
 * Created by Vladislav Bogdashkin on 23.09.2019.
 */

data class DealListModel(val deals:List<DealListModel>)


data class StatusModel(
    val orderId:Int,
    val title:String,
    val shortTitle:String
)

data class DealModel(
    val id:String,
    val estate_id:String,
    val opportunitySum:Int,
    val paymentSum:Int,
    val amount_pay_sum:Int,
    val statusId:Int,
    val managerName: String,
    val estate:EstateModel
)


data class EstateModel(
    val id:Int,
    val type:String,
    val number:String,
    val sectionBegin:Int?=null,
    val sectionEnd:Int?=null,
    val planPNG:PlanModel?,
    val planJPG:PlanModel?,
    val rooms:Int?=null,
    val albumId:Int?=null,
    val multitourId:Int?=null,
    val commonInfo:CommonInfoModel? = null,
    val explications:List<ExplicationListModel>? = null,
    val url:String?
)


fun fromRaw(raw:EstateRaw):EstateEntity{
    val entity = EstateEntity()
    entity.setId(raw.id)
    entity.setType(raw.type)
    entity.setNumber(raw.number)
    entity.setSectionBegin(raw.common_info.section_begin)
    entity.setSectionEnd(raw.common_info.section_end)
    entity.setPlanJpgUrl(raw.plan_jpg?.url)
    entity.setPlanJpgWidth(raw.plan_jpg?.width)
    entity.setPlanJpgHeight(raw.plan_jpg?.height)
    entity.setPlanPngUrl(raw.plan_png?.url)
    entity.setPlanPngWidth(raw.plan_png?.width)
    entity.setPlanPngHeight(raw.plan_png?.height)
    entity.setRooms(raw.common_info.rooms)
    entity.setAlbumId(raw.album_id)
    entity.setMultitourId(raw.multitour_id)

    entity.setUrl(raw.url)
    entity.setInfo_floor_max(raw.common_info.floor_max)
    entity.setInfo_area(raw.common_info.area)
    entity.setInfo_area_living(raw.common_info.area_living)
    entity.setInfo_kind(raw.common_info.kind)
    entity.setInfo_dependent(raw.common_info.dependent)
    entity.setInfo_decoration(raw.common_info.decoration)
    entity.setInfo_building(raw.common_info.building)
    entity.setInfo_section_begin(raw.common_info.section_begin)
    entity.setInfo_floor(raw.common_info.floor)

    entity.setInfo_window_face(raw.common_info.windows_face)
    entity.setInfo_price(raw.common_info.price)
    entity.setInfo_price_meter(raw.common_info.price_meter)
    entity.setInfo_ceiling(raw.common_info.ceiling)
    entity.setInfo_direction(raw.common_info.direction)
    return entity
}

data class PlanModel(
    val url:String,
    val width:Int,
    val height:Int
)


data class CommonInfoModel(
    val building: Int,
    val section_begin: Int,
    val floor: Int,
    val floor_max: Int,
    val area: Float?,
    val area_living: Float?,
    val kind: String?,
    val dependent:Boolean?=null,
    val decoration: String?,
    val ceiling: Float?,
    val windows_face: String?,
    val direction: String?,
    val price_meter: Int?,
    val price: Int?,
    val discount: Float?,
    val discount_amount: Int?,
    val rooms: Int?
)

data class ExplicationListModel(
    val planId:Int,
    val items:List<ExplicationModel>
)

data class ExplicationModel(
    val living: Boolean,
    val area: Float,
    val title: String
)

/*
data class CommonEstateInfoModel(
    val corpus:Int,
    val section:Int,
    val floor:Int,
    val totalFloors:Int,
    val totalArea:Float,
    val livingArea:Float,
    val rooms:Int,
    val flatType:String,
    val furnishType:String,
    val ceilingHieght:Float,
    val windowViewTGype:String,
    val sideOfTheWorld:String,
    val costPerM2:Float,
    val totalSum:Float
)
*/
